Read-only mirrors. Development, issues and pull requests are on GitHub.

summaryrefslogtreecommitdiffhomepage
path: root/docs/release-notes.md
diff options
context:
space:
mode:
authorMartin Hořeňovský2023-02-27 15:12:35 +0100
committerMartin Hořeňovský2023-02-27 15:12:49 +0100
commit3f0283de7a9c43200033da996ff9093be3ac84dc (patch)
treec8bed92387c305784eaf05b3a5f2567c674cfa1d /docs/release-notes.md
parent6fbb3f07235311d0c228b17b52406343a7aed8f2 (diff)
downloadcatch3-3.3.2.tar.gz
v3.3.2v3.3.2
Diffstat (limited to 'docs/release-notes.md')
-rw-r--r--docs/release-notes.md25
1 files changed, 24 insertions, 1 deletions
diff --git a/docs/release-notes.md b/docs/release-notes.md
index 3c46cb57..1fa37da4 100644
--- a/docs/release-notes.md
+++ b/docs/release-notes.md
@@ -2,6 +2,7 @@
# Release notes
**Contents**<br>
+[3.3.2](#332)<br>
[3.3.1](#331)<br>
[3.3.0](#330)<br>
[3.2.1](#321)<br>
@@ -56,6 +57,29 @@
+## 3.3.2
+
+### Improvements
+* Further reduced allocations
+ * The compact, console, TAP and XML reporters perform less allocations in various cases
+ * Removed 1 allocation per entered `SECTION`/`TEST_CASE`.
+ * Removed 2 allocations per test case exit, if stdout/stderr is captured
+* Improved performance
+ * Section tracking is 10%-25% faster than in v3.3.0
+ * Assertion handling is 5%-10% faster than in v3.3.0
+ * Test case registration is 1%-2% faster than in v3.3.0
+ * Tiny speedup for registering listeners
+ * Tiny speedup for `CAPTURE`, `TEST_CASE_METHOD`, `METHOD_AS_TEST_CASE`, and `TEMPLATE_LIST_TEST_*` macros.
+* `Contains`, `RangeEquals` and `UnorderedRangeEquals` matchers now support ranges with iterator + sentinel pair
+* Added `IsNaN` matcher
+ * Unlike `REQUIRE(isnan(x))`, `REQUIRE_THAT(x, IsNaN())` shows you the value of `x`.
+* Suppressed `declared_but_not_referenced` warning for NVHPC (#2637)
+
+### Fixes
+* Fixed performance regression in section tracking introduced in v3.3.1
+ * Extreme cases would cause the tracking to run about 4x slower than in 3.3.0
+
+
## 3.3.1
### Improvements
@@ -65,7 +89,6 @@
* The main improvement comes from smarter handling of `SECTION`s, especially sibling `SECTION`s
-
## 3.3.0
### Improvements